@@ -9,9 +9,9 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.CostExplorer 1.23.0\nVersion:         1.23.0\nBuilder version:"
-        " 7.5.14\nDocs:           "
-        " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce//\nBoto3 docs:     "
+        "Type annotations for boto3.CostExplorer 1.24.4\nVersion:         1.24.4\nBuilder version:"
+        " 7.6.1\nDocs:            https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce//\nBoto3"
+        " docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
         " https://github.com/youtype/mypy_boto3_builder/releases"
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.23.0")
+    print("1.24.4")
 
 
 def main() -> None:
