@@ -23,6 +23,8 @@ from .literals import (
     AnomalyFeedbackTypeType,
     AnomalySubscriptionFrequencyType,
     ContextType,
+    CostAllocationTagStatusType,
+    CostAllocationTagTypeType,
     DimensionType,
     GranularityType,
     LookbackPeriodInDaysType,
@@ -36,6 +38,7 @@ from .type_defs import (
     AnomalyDateIntervalTypeDef,
     AnomalyMonitorTypeDef,
     AnomalySubscriptionTypeDef,
+    CostAllocationTagStatusEntryTypeDef,
     CostCategoryRuleTypeDef,
     CostCategorySplitChargeRuleTypeDef,
     CreateAnomalyMonitorResponseTypeDef,
@@ -64,6 +67,7 @@ from .type_defs import (
     GetTagsResponseTypeDef,
     GetUsageForecastResponseTypeDef,
     GroupDefinitionTypeDef,
+    ListCostAllocationTagsResponseTypeDef,
     ListCostCategoryDefinitionsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     ProvideAnomalyFeedbackResponseTypeDef,
@@ -75,6 +79,7 @@ from .type_defs import (
     TotalImpactFilterTypeDef,
     UpdateAnomalyMonitorResponseTypeDef,
     UpdateAnomalySubscriptionResponseTypeDef,
+    UpdateCostAllocationTagsStatusResponseTypeDef,
     UpdateCostCategoryDefinitionResponseTypeDef,
 )
 
@@ -138,8 +143,8 @@ class CostExplorerClient(BaseClient):
     def create_anomaly_monitor(
         self,
         *,
-        AnomalyMonitor: "AnomalyMonitorTypeDef",
-        ResourceTags: Sequence["ResourceTagTypeDef"] = ...
+        AnomalyMonitor: AnomalyMonitorTypeDef,
+        ResourceTags: Sequence[ResourceTagTypeDef] = ...
     ) -> CreateAnomalyMonitorResponseTypeDef:
         """
         .
@@ -151,8 +156,8 @@ class CostExplorerClient(BaseClient):
     def create_anomaly_subscription(
         self,
         *,
-        AnomalySubscription: "AnomalySubscriptionTypeDef",
-        ResourceTags: Sequence["ResourceTagTypeDef"] = ...
+        AnomalySubscription: AnomalySubscriptionTypeDef,
+        ResourceTags: Sequence[ResourceTagTypeDef] = ...
     ) -> CreateAnomalySubscriptionResponseTypeDef:
         """
         .
@@ -166,10 +171,10 @@ class CostExplorerClient(BaseClient):
         *,
         Name: str,
         RuleVersion: Literal["CostCategoryExpression.v1"],
-        Rules: Sequence["CostCategoryRuleTypeDef"],
+        Rules: Sequence[CostCategoryRuleTypeDef],
         DefaultValue: str = ...,
-        SplitChargeRules: Sequence["CostCategorySplitChargeRuleTypeDef"] = ...,
-        ResourceTags: Sequence["ResourceTagTypeDef"] = ...
+        SplitChargeRules: Sequence[CostCategorySplitChargeRuleTypeDef] = ...,
+        ResourceTags: Sequence[ResourceTagTypeDef] = ...
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
         .
@@ -208,8 +213,8 @@ class CostExplorerClient(BaseClient):
         self, *, CostCategoryArn: str, EffectiveOn: str = ...
     ) -> DescribeCostCategoryDefinitionResponseTypeDef:
         """
-        Returns the name, ARN, rules, definition, and effective dates of a Cost Category
-        that's defined in the account.
+        Returns the name, Amazon Resource Name (ARN), rules, definition, and effective
+        dates of a Cost Category that's defined in the account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#describe_cost_category_definition)
@@ -232,10 +237,10 @@ class CostExplorerClient(BaseClient):
     def get_anomalies(
         self,
         *,
-        DateInterval: "AnomalyDateIntervalTypeDef",
+        DateInterval: AnomalyDateIntervalTypeDef,
         MonitorArn: str = ...,
         Feedback: AnomalyFeedbackTypeType = ...,
-        TotalImpact: "TotalImpactFilterTypeDef" = ...,
+        TotalImpact: TotalImpactFilterTypeDef = ...,
         NextPageToken: str = ...,
         MaxResults: int = ...
     ) -> GetAnomaliesResponseTypeDef:
@@ -279,11 +284,11 @@ class CostExplorerClient(BaseClient):
     def get_cost_and_usage(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
+        TimePeriod: DateIntervalTypeDef,
         Granularity: GranularityType,
         Metrics: Sequence[str],
         Filter: "ExpressionTypeDef" = ...,
-        GroupBy: Sequence["GroupDefinitionTypeDef"] = ...,
+        GroupBy: Sequence[GroupDefinitionTypeDef] = ...,
         NextPageToken: str = ...
     ) -> GetCostAndUsageResponseTypeDef:
         """
@@ -296,11 +301,11 @@ class CostExplorerClient(BaseClient):
     def get_cost_and_usage_with_resources(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
+        TimePeriod: DateIntervalTypeDef,
         Granularity: GranularityType,
         Filter: "ExpressionTypeDef",
         Metrics: Sequence[str] = ...,
-        GroupBy: Sequence["GroupDefinitionTypeDef"] = ...,
+        GroupBy: Sequence[GroupDefinitionTypeDef] = ...,
         NextPageToken: str = ...
     ) -> GetCostAndUsageWithResourcesResponseTypeDef:
         """
@@ -313,11 +318,11 @@ class CostExplorerClient(BaseClient):
     def get_cost_categories(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
+        TimePeriod: DateIntervalTypeDef,
         SearchString: str = ...,
         CostCategoryName: str = ...,
         Filter: "ExpressionTypeDef" = ...,
-        SortBy: Sequence["SortDefinitionTypeDef"] = ...,
+        SortBy: Sequence[SortDefinitionTypeDef] = ...,
         MaxResults: int = ...,
         NextPageToken: str = ...
     ) -> GetCostCategoriesResponseTypeDef:
@@ -331,7 +336,7 @@ class CostExplorerClient(BaseClient):
     def get_cost_forecast(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
+        TimePeriod: DateIntervalTypeDef,
         Metric: MetricType,
         Granularity: GranularityType,
         Filter: "ExpressionTypeDef" = ...,
@@ -348,12 +353,12 @@ class CostExplorerClient(BaseClient):
     def get_dimension_values(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
+        TimePeriod: DateIntervalTypeDef,
         Dimension: DimensionType,
         SearchString: str = ...,
         Context: ContextType = ...,
         Filter: "ExpressionTypeDef" = ...,
-        SortBy: Sequence["SortDefinitionTypeDef"] = ...,
+        SortBy: Sequence[SortDefinitionTypeDef] = ...,
         MaxResults: int = ...,
         NextPageToken: str = ...
     ) -> GetDimensionValuesResponseTypeDef:
@@ -368,17 +373,20 @@ class CostExplorerClient(BaseClient):
     def get_reservation_coverage(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
-        GroupBy: Sequence["GroupDefinitionTypeDef"] = ...,
+        TimePeriod: DateIntervalTypeDef,
+        GroupBy: Sequence[GroupDefinitionTypeDef] = ...,
         Granularity: GranularityType = ...,
         Filter: "ExpressionTypeDef" = ...,
         Metrics: Sequence[str] = ...,
         NextPageToken: str = ...,
-        SortBy: "SortDefinitionTypeDef" = ...,
+        SortBy: SortDefinitionTypeDef = ...,
         MaxResults: int = ...
     ) -> GetReservationCoverageResponseTypeDef:
         """
-        Retrieves the reservation coverage for your account.
+        Retrieves the reservation coverage for your account, which you can use to see
+        how much of your Amazon Elastic Compute Cloud, Amazon ElastiCache, Amazon
+        Relational Database Service, or Amazon Redshift usage is covered by a
+        reservation.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#get_reservation_coverage)
@@ -394,12 +402,12 @@ class CostExplorerClient(BaseClient):
         LookbackPeriodInDays: LookbackPeriodInDaysType = ...,
         TermInYears: TermInYearsType = ...,
         PaymentOption: PaymentOptionType = ...,
-        ServiceSpecification: "ServiceSpecificationTypeDef" = ...,
+        ServiceSpecification: ServiceSpecificationTypeDef = ...,
         PageSize: int = ...,
         NextPageToken: str = ...
     ) -> GetReservationPurchaseRecommendationResponseTypeDef:
         """
-        Gets recommendations for which reservations to purchase.
+        Gets recommendations for reservation purchases.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#get_reservation_purchase_recommendation)
@@ -408,11 +416,11 @@ class CostExplorerClient(BaseClient):
     def get_reservation_utilization(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
-        GroupBy: Sequence["GroupDefinitionTypeDef"] = ...,
+        TimePeriod: DateIntervalTypeDef,
+        GroupBy: Sequence[GroupDefinitionTypeDef] = ...,
         Granularity: GranularityType = ...,
         Filter: "ExpressionTypeDef" = ...,
-        SortBy: "SortDefinitionTypeDef" = ...,
+        SortBy: SortDefinitionTypeDef = ...,
         NextPageToken: str = ...,
         MaxResults: int = ...
     ) -> GetReservationUtilizationResponseTypeDef:
@@ -428,7 +436,7 @@ class CostExplorerClient(BaseClient):
         *,
         Service: str,
         Filter: "ExpressionTypeDef" = ...,
-        Configuration: "RightsizingRecommendationConfigurationTypeDef" = ...,
+        Configuration: RightsizingRecommendationConfigurationTypeDef = ...,
         PageSize: int = ...,
         NextPageToken: str = ...
     ) -> GetRightsizingRecommendationResponseTypeDef:
@@ -443,14 +451,14 @@ class CostExplorerClient(BaseClient):
     def get_savings_plans_coverage(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
-        GroupBy: Sequence["GroupDefinitionTypeDef"] = ...,
+        TimePeriod: DateIntervalTypeDef,
+        GroupBy: Sequence[GroupDefinitionTypeDef] = ...,
         Granularity: GranularityType = ...,
         Filter: "ExpressionTypeDef" = ...,
         Metrics: Sequence[str] = ...,
         NextToken: str = ...,
         MaxResults: int = ...,
-        SortBy: "SortDefinitionTypeDef" = ...
+        SortBy: SortDefinitionTypeDef = ...
     ) -> GetSavingsPlansCoverageResponseTypeDef:
         """
         Retrieves the Savings Plans covered for your account.
@@ -482,10 +490,10 @@ class CostExplorerClient(BaseClient):
     def get_savings_plans_utilization(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
+        TimePeriod: DateIntervalTypeDef,
         Granularity: GranularityType = ...,
         Filter: "ExpressionTypeDef" = ...,
-        SortBy: "SortDefinitionTypeDef" = ...
+        SortBy: SortDefinitionTypeDef = ...
     ) -> GetSavingsPlansUtilizationResponseTypeDef:
         """
         Retrieves the Savings Plans utilization for your account across date ranges with
@@ -498,12 +506,12 @@ class CostExplorerClient(BaseClient):
     def get_savings_plans_utilization_details(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
+        TimePeriod: DateIntervalTypeDef,
         Filter: "ExpressionTypeDef" = ...,
         DataType: Sequence[SavingsPlansDataTypeType] = ...,
         NextToken: str = ...,
         MaxResults: int = ...,
-        SortBy: "SortDefinitionTypeDef" = ...
+        SortBy: SortDefinitionTypeDef = ...
     ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
         """
         Retrieves attribute data along with aggregate utilization and savings data for a
@@ -516,11 +524,11 @@ class CostExplorerClient(BaseClient):
     def get_tags(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
+        TimePeriod: DateIntervalTypeDef,
         SearchString: str = ...,
         TagKey: str = ...,
         Filter: "ExpressionTypeDef" = ...,
-        SortBy: Sequence["SortDefinitionTypeDef"] = ...,
+        SortBy: Sequence[SortDefinitionTypeDef] = ...,
         MaxResults: int = ...,
         NextPageToken: str = ...
     ) -> GetTagsResponseTypeDef:
@@ -534,7 +542,7 @@ class CostExplorerClient(BaseClient):
     def get_usage_forecast(
         self,
         *,
-        TimePeriod: "DateIntervalTypeDef",
+        TimePeriod: DateIntervalTypeDef,
         Metric: MetricType,
         Granularity: GranularityType,
         Filter: "ExpressionTypeDef" = ...,
@@ -548,12 +556,28 @@ class CostExplorerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#get_usage_forecast)
         """
 
+    def list_cost_allocation_tags(
+        self,
+        *,
+        Status: CostAllocationTagStatusType = ...,
+        TagKeys: Sequence[str] = ...,
+        Type: CostAllocationTagTypeType = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...
+    ) -> ListCostAllocationTagsResponseTypeDef:
+        """
+        Get a list of cost allocation tags.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.list_cost_allocation_tags)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#list_cost_allocation_tags)
+        """
+
     def list_cost_category_definitions(
         self, *, EffectiveOn: str = ..., NextToken: str = ..., MaxResults: int = ...
     ) -> ListCostCategoryDefinitionsResponseTypeDef:
         """
-        Returns the name, ARN, `NumberOfRules` and effective dates of all Cost
-        Categories defined in the account.
+        Returns the name, Amazon Resource Name (ARN), `NumberOfRules` and effective
+        dates of all Cost Categories defined in the account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#list_cost_category_definitions)
@@ -578,7 +602,7 @@ class CostExplorerClient(BaseClient):
         """
 
     def tag_resource(
-        self, *, ResourceArn: str, ResourceTags: Sequence["ResourceTagTypeDef"]
+        self, *, ResourceArn: str, ResourceTags: Sequence[ResourceTagTypeDef]
     ) -> Dict[str, Any]:
         """
         .
@@ -612,7 +636,7 @@ class CostExplorerClient(BaseClient):
         Threshold: float = ...,
         Frequency: AnomalySubscriptionFrequencyType = ...,
         MonitorArnList: Sequence[str] = ...,
-        Subscribers: Sequence["SubscriberTypeDef"] = ...,
+        Subscribers: Sequence[SubscriberTypeDef] = ...,
         SubscriptionName: str = ...
     ) -> UpdateAnomalySubscriptionResponseTypeDef:
         """
@@ -622,14 +646,24 @@ class CostExplorerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#update_anomaly_subscription)
         """
 
+    def update_cost_allocation_tags_status(
+        self, *, CostAllocationTagsStatus: Sequence[CostAllocationTagStatusEntryTypeDef]
+    ) -> UpdateCostAllocationTagsStatusResponseTypeDef:
+        """
+        Updates status for cost allocation tags in bulk, with maximum batch size of 20.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.update_cost_allocation_tags_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#update_cost_allocation_tags_status)
+        """
+
     def update_cost_category_definition(
         self,
         *,
         CostCategoryArn: str,
         RuleVersion: Literal["CostCategoryExpression.v1"],
-        Rules: Sequence["CostCategoryRuleTypeDef"],
+        Rules: Sequence[CostCategoryRuleTypeDef],
         DefaultValue: str = ...,
-        SplitChargeRules: Sequence["CostCategorySplitChargeRuleTypeDef"] = ...
+        SplitChargeRules: Sequence[CostCategorySplitChargeRuleTypeDef] = ...
     ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
         Updates an existing Cost Category.
