@@ -24,6 +24,8 @@ __all__ = (
     "AnomalyFeedbackTypeType",
     "AnomalySubscriptionFrequencyType",
     "ContextType",
+    "CostAllocationTagStatusType",
+    "CostAllocationTagTypeType",
     "CostCategoryInheritedValueDimensionNameType",
     "CostCategoryRuleTypeType",
     "CostCategoryRuleVersionType",
@@ -62,6 +64,8 @@ AccountScopeType = Literal["LINKED", "PAYER"]
 AnomalyFeedbackTypeType = Literal["NO", "PLANNED_ACTIVITY", "YES"]
 AnomalySubscriptionFrequencyType = Literal["DAILY", "IMMEDIATE", "WEEKLY"]
 ContextType = Literal["COST_AND_USAGE", "RESERVATIONS", "SAVINGS_PLANS"]
+CostAllocationTagStatusType = Literal["Active", "Inactive"]
+CostAllocationTagTypeType = Literal["AWSGenerated", "UserDefined"]
 CostCategoryInheritedValueDimensionNameType = Literal["LINKED_ACCOUNT_NAME", "TAG"]
 CostCategoryRuleTypeType = Literal["INHERITED_VALUE", "REGULAR"]
 CostCategoryRuleVersionType = Literal["CostCategoryExpression.v1"]
@@ -272,6 +276,7 @@ ServiceName = Literal[
     "elbv2",
     "emr",
     "emr-containers",
+    "emr-serverless",
     "es",
     "events",
     "evidently",
